@@ -31,7 +31,6 @@
 
 #include <glib.h>
 #include <X11/Xlib.h>
-#include "eventqueue.h"
 #include "common.h"
 #include "boxes.h"
 #include "display.h"
@@ -130,7 +129,6 @@ struct _MetaDisplay
 
   /*< private-ish >*/
   guint error_trap_synced_at_last_pop : 1;
-  MetaEventQueue *events;
   MetaScreen *screen;
   GHashTable *window_ids;
   int error_traps;
@@ -220,8 +218,8 @@ struct _MetaDisplay
   unsigned int super_mask;
   unsigned int meta_mask;
 
-  /* Xinerama cache */
-  unsigned int xinerama_cache_invalidated : 1;
+  /* Monitor cache */
+  unsigned int monitor_cache_invalidated : 1;
 
   /* Opening the display */
   unsigned int display_opening : 1;
@@ -377,9 +375,8 @@ void meta_display_grab_focus_window_button   (MetaDisplay *display,
 void meta_display_ungrab_focus_window_button (MetaDisplay *display,
                                               MetaWindow  *window);
 
-/* Next two functions are defined in edge-resistance.c */
-void meta_display_compute_resistance_and_snapping_edges (MetaDisplay *display);
-void meta_display_cleanup_edges                         (MetaDisplay *display);
+/* Next function is defined in edge-resistance.c */
+void meta_display_cleanup_edges              (MetaDisplay *display);
 
 /* make a request to ensure the event serial has changed */
 void     meta_display_increment_event_serial (MetaDisplay *display);
